@@ -23,15 +23,11 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.aws_iam
+from ._jsii import *
+
 import aws_cdk.aws_lambda
-import aws_cdk.aws_s3
 import aws_cdk.aws_sns
 import aws_cdk.core
-import aws_cdk.cx_api
-import constructs
-
-from ._jsii import *
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
@@ -54,6 +50,25 @@ class CfnCustomResource(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
 
         jsii.create(CfnCustomResource, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnCustomResource":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -94,7 +109,7 @@ class CfnCustomResource(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         return jsii.get(self, "serviceToken")
 
     @service_token.setter
-    def service_token(self, value: str):
+    def service_token(self, value: str) -> None:
         jsii.set(self, "serviceToken", value)
 
 
@@ -155,6 +170,25 @@ class CfnMacro(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
 
         jsii.create(CfnMacro, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnMacro":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -195,7 +229,7 @@ class CfnMacro(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "functionName")
 
     @function_name.setter
-    def function_name(self, value: str):
+    def function_name(self, value: str) -> None:
         jsii.set(self, "functionName", value)
 
     @builtins.property
@@ -209,7 +243,7 @@ class CfnMacro(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
@@ -223,7 +257,7 @@ class CfnMacro(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "description")
 
     @description.setter
-    def description(self, value: typing.Optional[str]):
+    def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
     @builtins.property
@@ -237,7 +271,7 @@ class CfnMacro(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "logGroupName")
 
     @log_group_name.setter
-    def log_group_name(self, value: typing.Optional[str]):
+    def log_group_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "logGroupName", value)
 
     @builtins.property
@@ -251,7 +285,7 @@ class CfnMacro(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "logRoleArn")
 
     @log_role_arn.setter
-    def log_role_arn(self, value: typing.Optional[str]):
+    def log_role_arn(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "logRoleArn", value)
 
 
@@ -341,7 +375,7 @@ class CfnStack(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
     cloudformationResource:
     :cloudformationResource:: AWS::CloudFormation::Stack
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, template_url: str, notification_arns: typing.Optional[typing.List[str]]=None, parameters: typing.Optional[typing.Union[typing.Optional[typing.Mapping[str, str]], typing.Optional[aws_cdk.core.IResolvable]]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, timeout_in_minutes: typing.Optional[jsii.Number]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, template_url: str, notification_arns: typing.Optional[typing.List[str]]=None, parameters: typing.Optional[typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, timeout_in_minutes: typing.Optional[jsii.Number]=None) -> None:
         """Create a new ``AWS::CloudFormation::Stack``.
 
         :param scope: - scope in which this resource is defined.
@@ -356,6 +390,25 @@ class CfnStack(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
 
         jsii.create(CfnStack, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnStack":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -406,7 +459,7 @@ class CfnStack(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "templateUrl")
 
     @template_url.setter
-    def template_url(self, value: str):
+    def template_url(self, value: str) -> None:
         jsii.set(self, "templateUrl", value)
 
     @builtins.property
@@ -420,12 +473,12 @@ class CfnStack(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "notificationArns")
 
     @notification_arns.setter
-    def notification_arns(self, value: typing.Optional[typing.List[str]]):
+    def notification_arns(self, value: typing.Optional[typing.List[str]]) -> None:
         jsii.set(self, "notificationArns", value)
 
     @builtins.property
     @jsii.member(jsii_name="parameters")
-    def parameters(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.Mapping[str, str]]]]:
+    def parameters(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]]:
         """``AWS::CloudFormation::Stack.Parameters``.
 
         see
@@ -434,7 +487,7 @@ class CfnStack(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "parameters")
 
     @parameters.setter
-    def parameters(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.Mapping[str, str]]]]):
+    def parameters(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]]) -> None:
         jsii.set(self, "parameters", value)
 
     @builtins.property
@@ -448,13 +501,13 @@ class CfnStack(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "timeoutInMinutes")
 
     @timeout_in_minutes.setter
-    def timeout_in_minutes(self, value: typing.Optional[jsii.Number]):
+    def timeout_in_minutes(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "timeoutInMinutes", value)
 
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-cloudformation.CfnStackProps", jsii_struct_bases=[], name_mapping={'template_url': 'templateUrl', 'notification_arns': 'notificationArns', 'parameters': 'parameters', 'tags': 'tags', 'timeout_in_minutes': 'timeoutInMinutes'})
 class CfnStackProps():
-    def __init__(self, *, template_url: str, notification_arns: typing.Optional[typing.List[str]]=None, parameters: typing.Optional[typing.Union[typing.Optional[typing.Mapping[str, str]], typing.Optional[aws_cdk.core.IResolvable]]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, timeout_in_minutes: typing.Optional[jsii.Number]=None) -> None:
+    def __init__(self, *, template_url: str, notification_arns: typing.Optional[typing.List[str]]=None, parameters: typing.Optional[typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, timeout_in_minutes: typing.Optional[jsii.Number]=None) -> None:
         """Properties for defining a ``AWS::CloudFormation::Stack``.
 
         :param template_url: ``AWS::CloudFormation::Stack.TemplateURL``.
@@ -493,7 +546,7 @@ class CfnStackProps():
         return self._values.get('notification_arns')
 
     @builtins.property
-    def parameters(self) -> typing.Optional[typing.Union[typing.Optional[typing.Mapping[str, str]], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def parameters(self) -> typing.Optional[typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]]:
         """``AWS::CloudFormation::Stack.Parameters``.
 
         see
@@ -551,6 +604,25 @@ class CfnWaitCondition(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
 
         jsii.create(CfnWaitCondition, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnWaitCondition":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -600,7 +672,7 @@ class CfnWaitCondition(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.get(self, "count")
 
     @count.setter
-    def count(self, value: typing.Optional[jsii.Number]):
+    def count(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "count", value)
 
     @builtins.property
@@ -614,7 +686,7 @@ class CfnWaitCondition(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.get(self, "handle")
 
     @handle.setter
-    def handle(self, value: typing.Optional[str]):
+    def handle(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "handle", value)
 
     @builtins.property
@@ -628,7 +700,7 @@ class CfnWaitCondition(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.get(self, "timeout")
 
     @timeout.setter
-    def timeout(self, value: typing.Optional[str]):
+    def timeout(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "timeout", value)
 
 
@@ -649,6 +721,25 @@ class CfnWaitConditionHandle(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta,
         """
         jsii.create(CfnWaitConditionHandle, self, [scope, id])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnWaitConditionHandle":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
